/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsproxywidget.sip"
#include <qgraphicsproxywidget.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsitem.sip"
#include <qgraphicsitem.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 509 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 199 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 224 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 103 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 384 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 363 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 63 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 119 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 88 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 69 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 72 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 164 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 75 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 139 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 78 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 471 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 81 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 460 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 84 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 87 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 90 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 1031 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 93 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 164 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 96 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 99 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 438 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 102 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 105 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 108 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainterpath.sip"
#include <qpainterpath.h>
#line 111 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 114 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qaction.sip"
#include <qaction.h>
#line 117 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 120 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicswidget.sip"
#include <qgraphicswidget.h>
#line 123 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 126 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 115 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 129 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 132 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 135 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 138 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicslayout.sip"
#include <qgraphicslayout.h>
#line 141 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 144 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 152 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 155 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 158 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 161 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 164 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 167 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 170 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 173 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 176 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 179 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 182 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 185 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 188 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicstransform.sip"
#include <qgraphicstransform.h>
#line 191 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 194 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 607 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsitem.sip"
#include <qgraphicsitem.h>
#line 197 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qtransform.sip"
#include <qtransform.h>
#line 200 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 203 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 206 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 209 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 329 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpolygon.sip"
#include <qpolygon.h>
#line 212 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 215 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 218 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsitem.sip"
#include <qgraphicsitem.h>
#line 221 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 578 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsitem.sip"
#include <qgraphicsitem.h>
#line 224 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsscene.sip"
#include <qgraphicsscene.h>
#line 227 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicslayoutitem.sip"
#include <qgraphicslayoutitem.h>
#line 230 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 233 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"


class sipQGraphicsProxyWidget : public ::QGraphicsProxyWidget
{
public:
    sipQGraphicsProxyWidget(::QGraphicsItem*, ::Qt::WindowFlags);
    virtual ~sipQGraphicsProxyWidget();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void advance(int) SIP_OVERRIDE;
    ::QRectF boundingRect() const SIP_OVERRIDE;
    ::QPainterPath shape() const SIP_OVERRIDE;
    bool contains(const ::QPointF&) const SIP_OVERRIDE;
    bool collidesWithItem(const ::QGraphicsItem*, ::Qt::ItemSelectionMode) const SIP_OVERRIDE;
    bool collidesWithPath(const ::QPainterPath&, ::Qt::ItemSelectionMode) const SIP_OVERRIDE;
    bool isObscuredBy(const ::QGraphicsItem*) const SIP_OVERRIDE;
    ::QPainterPath opaqueArea() const SIP_OVERRIDE;
    void paint(::QPainter*, const ::QStyleOptionGraphicsItem*, ::QWidget*) SIP_OVERRIDE;
    int type() const SIP_OVERRIDE;
    void contextMenuEvent(::QGraphicsSceneContextMenuEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QGraphicsSceneDragDropEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QGraphicsSceneDragDropEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QGraphicsSceneDragDropEvent*) SIP_OVERRIDE;
    void dropEvent(::QGraphicsSceneDragDropEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void hoverEnterEvent(::QGraphicsSceneHoverEvent*) SIP_OVERRIDE;
    void hoverLeaveEvent(::QGraphicsSceneHoverEvent*) SIP_OVERRIDE;
    void hoverMoveEvent(::QGraphicsSceneHoverEvent*) SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    ::QVariant itemChange(::QGraphicsItem::GraphicsItemChange, const ::QVariant&) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QGraphicsSceneMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QGraphicsSceneMouseEvent*) SIP_OVERRIDE;
    void mousePressEvent(::QGraphicsSceneMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QGraphicsSceneMouseEvent*) SIP_OVERRIDE;
    bool sceneEvent(::QEvent*) SIP_OVERRIDE;
    bool sceneEventFilter(::QGraphicsItem*, ::QEvent*) SIP_OVERRIDE;
    void wheelEvent(::QGraphicsSceneWheelEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    ::QSizeF sizeHint(::Qt::SizeHint, const ::QSizeF&) const SIP_OVERRIDE;
    void updateGeometry() SIP_OVERRIDE;
    void getContentsMargins(::qreal*, ::qreal*, ::qreal*, ::qreal*) const SIP_OVERRIDE;
    void setGeometry(const ::QRectF&) SIP_OVERRIDE;
    void paintWindowFrame(::QPainter*, const ::QStyleOptionGraphicsItem*, ::QWidget*) SIP_OVERRIDE;
    void initStyleOption(::QStyleOption*) const SIP_OVERRIDE;
    bool windowFrameEvent(::QEvent*) SIP_OVERRIDE;
    ::Qt::WindowFrameSection windowFrameSectionAt(const ::QPointF&) const SIP_OVERRIDE;
    void changeEvent(::QEvent*) SIP_OVERRIDE;
    void closeEvent(::QCloseEvent*) SIP_OVERRIDE;
    bool focusNextPrevChild(bool) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void moveEvent(::QGraphicsSceneMoveEvent*) SIP_OVERRIDE;
    void polishEvent() SIP_OVERRIDE;
    void resizeEvent(::QGraphicsSceneResizeEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void grabMouseEvent(::QEvent*) SIP_OVERRIDE;
    void ungrabMouseEvent(::QEvent*) SIP_OVERRIDE;
    void grabKeyboardEvent(::QEvent*) SIP_OVERRIDE;
    void ungrabKeyboardEvent(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQGraphicsProxyWidget(const sipQGraphicsProxyWidget &);
    sipQGraphicsProxyWidget &operator = (const sipQGraphicsProxyWidget &);

    char sipPyMethods[59];
};

sipQGraphicsProxyWidget::sipQGraphicsProxyWidget(::QGraphicsItem*a0, ::Qt::WindowFlags a1): ::QGraphicsProxyWidget(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQGraphicsProxyWidget::~sipQGraphicsProxyWidget()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQGraphicsProxyWidget::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWidgets_qt_metaobject(sipPySelf, sipType_QGraphicsProxyWidget);

    return ::QGraphicsProxyWidget::metaObject();
}

int sipQGraphicsProxyWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QGraphicsProxyWidget::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWidgets_qt_metacall(sipPySelf, sipType_QGraphicsProxyWidget, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQGraphicsProxyWidget::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWidgets_qt_metacast(sipPySelf, sipType_QGraphicsProxyWidget, _clname, &sipCpp) ? sipCpp : ::QGraphicsProxyWidget::qt_metacast(_clname));
}

void sipQGraphicsProxyWidget::advance(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_advance);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::advance(a0);
        return;
    }

    extern void sipVH_QtWidgets_59(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtWidgets_59(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QRectF sipQGraphicsProxyWidget::boundingRect() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_boundingRect);

    if (!sipMeth)
        return ::QGraphicsProxyWidget::boundingRect();

    extern ::QRectF sipVH_QtWidgets_144(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_144(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QPainterPath sipQGraphicsProxyWidget::shape() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_shape);

    if (!sipMeth)
        return ::QGraphicsProxyWidget::shape();

    extern ::QPainterPath sipVH_QtWidgets_145(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_145(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQGraphicsProxyWidget::contains(const ::QPointF& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_contains);

    if (!sipMeth)
        return ::QGraphicsProxyWidget::contains(a0);

    extern bool sipVH_QtWidgets_146(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPointF&);

    return sipVH_QtWidgets_146(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGraphicsProxyWidget::collidesWithItem(const ::QGraphicsItem*a0, ::Qt::ItemSelectionMode a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[4]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_collidesWithItem);

    if (!sipMeth)
        return ::QGraphicsProxyWidget::collidesWithItem(a0, a1);

    extern bool sipVH_QtWidgets_147(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QGraphicsItem*, ::Qt::ItemSelectionMode);

    return sipVH_QtWidgets_147(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQGraphicsProxyWidget::collidesWithPath(const ::QPainterPath& a0, ::Qt::ItemSelectionMode a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[5]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_collidesWithPath);

    if (!sipMeth)
        return ::QGraphicsProxyWidget::collidesWithPath(a0, a1);

    extern bool sipVH_QtWidgets_148(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPainterPath&, ::Qt::ItemSelectionMode);

    return sipVH_QtWidgets_148(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQGraphicsProxyWidget::isObscuredBy(const ::QGraphicsItem*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[6]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_isObscuredBy);

    if (!sipMeth)
        return ::QGraphicsProxyWidget::isObscuredBy(a0);

    extern bool sipVH_QtWidgets_149(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QGraphicsItem*);

    return sipVH_QtWidgets_149(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPainterPath sipQGraphicsProxyWidget::opaqueArea() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_opaqueArea);

    if (!sipMeth)
        return ::QGraphicsProxyWidget::opaqueArea();

    extern ::QPainterPath sipVH_QtWidgets_145(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_145(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQGraphicsProxyWidget::paint(::QPainter*a0, const ::QStyleOptionGraphicsItem*a1, ::QWidget*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_paint);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::paint(a0, a1, a2);
        return;
    }

    extern void sipVH_QtWidgets_150(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*, const ::QStyleOptionGraphicsItem*, ::QWidget*);

    sipVH_QtWidgets_150(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

int sipQGraphicsProxyWidget::type() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_type);

    if (!sipMeth)
        return ::QGraphicsProxyWidget::type();

    extern int sipVH_QtWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQGraphicsProxyWidget::contextMenuEvent(::QGraphicsSceneContextMenuEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_contextMenuEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::contextMenuEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_151(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneContextMenuEvent*);

    sipVH_QtWidgets_151(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::dragEnterEvent(::QGraphicsSceneDragDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_dragEnterEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::dragEnterEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_152(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneDragDropEvent*);

    sipVH_QtWidgets_152(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::dragLeaveEvent(::QGraphicsSceneDragDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_dragLeaveEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::dragLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_152(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneDragDropEvent*);

    sipVH_QtWidgets_152(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::dragMoveEvent(::QGraphicsSceneDragDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_dragMoveEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::dragMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_152(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneDragDropEvent*);

    sipVH_QtWidgets_152(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::dropEvent(::QGraphicsSceneDragDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_dropEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::dropEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_152(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneDragDropEvent*);

    sipVH_QtWidgets_152(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::focusInEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_focusInEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::focusInEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::focusOutEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_focusOutEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::focusOutEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::hoverEnterEvent(::QGraphicsSceneHoverEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_hoverEnterEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::hoverEnterEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_153(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneHoverEvent*);

    sipVH_QtWidgets_153(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::hoverLeaveEvent(::QGraphicsSceneHoverEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_hoverLeaveEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::hoverLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_153(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneHoverEvent*);

    sipVH_QtWidgets_153(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::hoverMoveEvent(::QGraphicsSceneHoverEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_hoverMoveEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::hoverMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_153(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneHoverEvent*);

    sipVH_QtWidgets_153(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::inputMethodEvent(::QInputMethodEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_inputMethodEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::inputMethodEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QInputMethodEvent*);

    sipVH_QtWidgets_29(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQGraphicsProxyWidget::inputMethodQuery(::Qt::InputMethodQuery a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[21]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_inputMethodQuery);

    if (!sipMeth)
        return ::QGraphicsProxyWidget::inputMethodQuery(a0);

    extern ::QVariant sipVH_QtWidgets_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::InputMethodQuery);

    return sipVH_QtWidgets_30(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQGraphicsProxyWidget::itemChange(::QGraphicsItem::GraphicsItemChange a0, const ::QVariant& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_itemChange);

    if (!sipMeth)
        return ::QGraphicsProxyWidget::itemChange(a0, a1);

    extern ::QVariant sipVH_QtWidgets_154(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsItem::GraphicsItemChange, const ::QVariant&);

    return sipVH_QtWidgets_154(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQGraphicsProxyWidget::keyPressEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_keyPressEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::keyPressEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::keyReleaseEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_keyReleaseEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::mouseDoubleClickEvent(::QGraphicsSceneMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_155(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneMouseEvent*);

    sipVH_QtWidgets_155(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::mouseMoveEvent(::QGraphicsSceneMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_155(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneMouseEvent*);

    sipVH_QtWidgets_155(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::mousePressEvent(::QGraphicsSceneMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::mousePressEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_155(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneMouseEvent*);

    sipVH_QtWidgets_155(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::mouseReleaseEvent(::QGraphicsSceneMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_155(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneMouseEvent*);

    sipVH_QtWidgets_155(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGraphicsProxyWidget::sceneEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[29], &sipPySelf, SIP_NULLPTR, sipName_sceneEvent);

    if (!sipMeth)
        return ::QGraphicsProxyWidget::sceneEvent(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGraphicsProxyWidget::sceneEventFilter(::QGraphicsItem*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[30], &sipPySelf, SIP_NULLPTR, sipName_sceneEventFilter);

    if (!sipMeth)
        return ::QGraphicsProxyWidget::sceneEventFilter(a0, a1);

    extern bool sipVH_QtWidgets_156(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsItem*, ::QEvent*);

    return sipVH_QtWidgets_156(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQGraphicsProxyWidget::wheelEvent(::QGraphicsSceneWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[31], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_157(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneWheelEvent*);

    sipVH_QtWidgets_157(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGraphicsProxyWidget::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[32], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QGraphicsProxyWidget::event(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGraphicsProxyWidget::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[33], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QGraphicsProxyWidget::eventFilter(a0, a1);

    extern bool sipVH_QtWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQGraphicsProxyWidget::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[34], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[35], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::childEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[36], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::customEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[37], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[38], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSizeF sipQGraphicsProxyWidget::sizeHint(::Qt::SizeHint a0, const ::QSizeF& a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[39]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHint);

    if (!sipMeth)
        return ::QGraphicsProxyWidget::sizeHint(a0, a1);

    extern ::QSizeF sipVH_QtWidgets_140(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::SizeHint, const ::QSizeF&);

    return sipVH_QtWidgets_140(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQGraphicsProxyWidget::updateGeometry()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[40], &sipPySelf, SIP_NULLPTR, sipName_updateGeometry);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::updateGeometry();
        return;
    }

    extern void sipVH_QtWidgets_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_37(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQGraphicsProxyWidget::getContentsMargins(::qreal*a0, ::qreal*a1, ::qreal*a2, ::qreal*a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[41]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_getContentsMargins);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::getContentsMargins(a0, a1, a2, a3);
        return;
    }

    extern void sipVH_QtWidgets_139(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::qreal*, ::qreal*, ::qreal*, ::qreal*);

    sipVH_QtWidgets_139(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

void sipQGraphicsProxyWidget::setGeometry(const ::QRectF& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[42], &sipPySelf, SIP_NULLPTR, sipName_setGeometry);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::setGeometry(a0);
        return;
    }

    extern void sipVH_QtWidgets_138(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QRectF&);

    sipVH_QtWidgets_138(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::paintWindowFrame(::QPainter*a0, const ::QStyleOptionGraphicsItem*a1, ::QWidget*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[43], &sipPySelf, SIP_NULLPTR, sipName_paintWindowFrame);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::paintWindowFrame(a0, a1, a2);
        return;
    }

    extern void sipVH_QtWidgets_150(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*, const ::QStyleOptionGraphicsItem*, ::QWidget*);

    sipVH_QtWidgets_150(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQGraphicsProxyWidget::initStyleOption(::QStyleOption*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[44]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initStyleOption);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::initStyleOption(a0);
        return;
    }

    extern void sipVH_QtWidgets_158(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyleOption*);

    sipVH_QtWidgets_158(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGraphicsProxyWidget::windowFrameEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[45], &sipPySelf, SIP_NULLPTR, sipName_windowFrameEvent);

    if (!sipMeth)
        return ::QGraphicsProxyWidget::windowFrameEvent(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::Qt::WindowFrameSection sipQGraphicsProxyWidget::windowFrameSectionAt(const ::QPointF& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[46]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_windowFrameSectionAt);

    if (!sipMeth)
        return ::QGraphicsProxyWidget::windowFrameSectionAt(a0);

    extern ::Qt::WindowFrameSection sipVH_QtWidgets_159(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPointF&);

    return sipVH_QtWidgets_159(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::changeEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[47], &sipPySelf, SIP_NULLPTR, sipName_changeEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::changeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::closeEvent(::QCloseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[48], &sipPySelf, SIP_NULLPTR, sipName_closeEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::closeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCloseEvent*);

    sipVH_QtWidgets_19(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGraphicsProxyWidget::focusNextPrevChild(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[49], &sipPySelf, SIP_NULLPTR, sipName_focusNextPrevChild);

    if (!sipMeth)
        return ::QGraphicsProxyWidget::focusNextPrevChild(a0);

    extern bool sipVH_QtWidgets_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_QtWidgets_31(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::hideEvent(::QHideEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[50], &sipPySelf, SIP_NULLPTR, sipName_hideEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::hideEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QHideEvent*);

    sipVH_QtWidgets_28(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::moveEvent(::QGraphicsSceneMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[51], &sipPySelf, SIP_NULLPTR, sipName_moveEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::moveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_160(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneMoveEvent*);

    sipVH_QtWidgets_160(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::polishEvent()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[52], &sipPySelf, SIP_NULLPTR, sipName_polishEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::polishEvent();
        return;
    }

    extern void sipVH_QtWidgets_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_37(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQGraphicsProxyWidget::resizeEvent(::QGraphicsSceneResizeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[53], &sipPySelf, SIP_NULLPTR, sipName_resizeEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::resizeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_161(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneResizeEvent*);

    sipVH_QtWidgets_161(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::showEvent(::QShowEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[54], &sipPySelf, SIP_NULLPTR, sipName_showEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::showEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QShowEvent*);

    sipVH_QtWidgets_27(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::grabMouseEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[55], &sipPySelf, SIP_NULLPTR, sipName_grabMouseEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::grabMouseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::ungrabMouseEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[56], &sipPySelf, SIP_NULLPTR, sipName_ungrabMouseEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::ungrabMouseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::grabKeyboardEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[57], &sipPySelf, SIP_NULLPTR, sipName_grabKeyboardEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::grabKeyboardEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsProxyWidget::ungrabKeyboardEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[58], &sipPySelf, SIP_NULLPTR, sipName_ungrabKeyboardEvent);

    if (!sipMeth)
    {
        ::QGraphicsProxyWidget::ungrabKeyboardEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_setWidget, "setWidget(self, widget: Optional[QWidget])");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_setWidget(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_setWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWidget* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QWidget, &a0))
        {
#line 34 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsproxywidget.sip"
        // The ownership of any existing widget must be passed back to Python.
        QWidget *w = sipCpp->widget();
        
        Py_BEGIN_ALLOW_THREADS
        sipCpp->setWidget(a0);
        Py_END_ALLOW_THREADS
        
        if (w)
        {
            PyObject *wo = sipGetPyObject(w, sipType_QWidget);
        
            if (wo)
                sipTransferBack(wo);
        }
#line 1397 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsProxyWidget.cpp"

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_setWidget, doc_QGraphicsProxyWidget_setWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_widget, "widget(self) -> Optional[QWidget]");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_widget(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_widget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp))
        {
            ::QWidget*sipRes;

            sipRes = sipCpp->widget();

            return sipConvertFromType(sipRes, sipType_QWidget, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_widget, doc_QGraphicsProxyWidget_widget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_subWidgetRect, "subWidgetRect(self, widget: Optional[QWidget]) -> QRectF");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_subWidgetRect(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_subWidgetRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWidget* a0;
        const ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QWidget, &a0))
        {
            ::QRectF*sipRes;

            sipRes = new ::QRectF(sipCpp->subWidgetRect(a0));

            return sipConvertFromNewType(sipRes, sipType_QRectF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_subWidgetRect, doc_QGraphicsProxyWidget_subWidgetRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_setGeometry, "setGeometry(self, rect: QRectF)");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_setGeometry(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_setGeometry(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QRectF* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QRectF, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::setGeometry(*a0) : sipCpp->setGeometry(*a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_setGeometry, doc_QGraphicsProxyWidget_setGeometry);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_paint, "paint(self, painter: Optional[QPainter], option: Optional[QStyleOptionGraphicsItem], widget: Optional[QWidget])");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_paint(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_paint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPainter* a0;
        const ::QStyleOptionGraphicsItem* a1;
        ::QWidget* a2;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8J8J8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QPainter, &a0, sipType_QStyleOptionGraphicsItem, &a1, sipType_QWidget, &a2))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::paint(a0, a1, a2) : sipCpp->paint(a0, a1, a2));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_paint, doc_QGraphicsProxyWidget_paint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_type, "type(self) -> int");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_type(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::type() : sipCpp->type());

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_type, doc_QGraphicsProxyWidget_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_createProxyForChildWidget, "createProxyForChildWidget(self, child: Optional[QWidget]) -> Optional[QGraphicsProxyWidget]");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_createProxyForChildWidget(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_createProxyForChildWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWidget* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QWidget, &a0))
        {
            ::QGraphicsProxyWidget*sipRes;

            sipRes = sipCpp->createProxyForChildWidget(a0);

            return sipConvertFromNewType(sipRes, sipType_QGraphicsProxyWidget, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_createProxyForChildWidget, doc_QGraphicsProxyWidget_createProxyForChildWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_itemChange, "itemChange(self, change: QGraphicsItem.GraphicsItemChange, value: Any) -> Any");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_itemChange(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_itemChange(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsItem::GraphicsItemChange a0;
        const ::QVariant* a1;
        int a1State = 0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pEJ1", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QGraphicsItem_GraphicsItemChange, &a0, sipType_QVariant, &a1, &a1State))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant((sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::itemChange(a0, *a1) : sipCpp->itemChange(a0, *a1)));
            sipReleaseType(const_cast< ::QVariant *>(a1), sipType_QVariant, a1State);

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_itemChange, doc_QGraphicsProxyWidget_itemChange);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_event, "event(self, event: Optional[QEvent]) -> bool");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_event(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_event(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::event(a0) : sipCpp->event(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_event, doc_QGraphicsProxyWidget_event);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_eventFilter, "eventFilter(self, object: Optional[QObject], event: Optional[QEvent]) -> bool");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_eventFilter(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_eventFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QObject* a0;
        ::QEvent* a1;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8J8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QObject, &a0, sipType_QEvent, &a1))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::eventFilter(a0, a1) : sipCpp->eventFilter(a0, a1));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_eventFilter, doc_QGraphicsProxyWidget_eventFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_showEvent, "showEvent(self, event: Optional[QShowEvent])");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_showEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_showEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QShowEvent* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QShowEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::showEvent(a0) : sipCpp->showEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_showEvent, doc_QGraphicsProxyWidget_showEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_hideEvent, "hideEvent(self, event: Optional[QHideEvent])");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_hideEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_hideEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QHideEvent* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QHideEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::hideEvent(a0) : sipCpp->hideEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_hideEvent, doc_QGraphicsProxyWidget_hideEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_contextMenuEvent, "contextMenuEvent(self, event: Optional[QGraphicsSceneContextMenuEvent])");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_contextMenuEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_contextMenuEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsSceneContextMenuEvent* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QGraphicsSceneContextMenuEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::contextMenuEvent(a0) : sipCpp->contextMenuEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_contextMenuEvent, doc_QGraphicsProxyWidget_contextMenuEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_hoverEnterEvent, "hoverEnterEvent(self, event: Optional[QGraphicsSceneHoverEvent])");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_hoverEnterEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_hoverEnterEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsSceneHoverEvent* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QGraphicsSceneHoverEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::hoverEnterEvent(a0) : sipCpp->hoverEnterEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_hoverEnterEvent, doc_QGraphicsProxyWidget_hoverEnterEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_hoverLeaveEvent, "hoverLeaveEvent(self, event: Optional[QGraphicsSceneHoverEvent])");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_hoverLeaveEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_hoverLeaveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsSceneHoverEvent* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QGraphicsSceneHoverEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::hoverLeaveEvent(a0) : sipCpp->hoverLeaveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_hoverLeaveEvent, doc_QGraphicsProxyWidget_hoverLeaveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_hoverMoveEvent, "hoverMoveEvent(self, event: Optional[QGraphicsSceneHoverEvent])");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_hoverMoveEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_hoverMoveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsSceneHoverEvent* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QGraphicsSceneHoverEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::hoverMoveEvent(a0) : sipCpp->hoverMoveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_hoverMoveEvent, doc_QGraphicsProxyWidget_hoverMoveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_grabMouseEvent, "grabMouseEvent(self, event: Optional[QEvent])");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_grabMouseEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_grabMouseEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::grabMouseEvent(a0) : sipCpp->grabMouseEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_grabMouseEvent, doc_QGraphicsProxyWidget_grabMouseEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_ungrabMouseEvent, "ungrabMouseEvent(self, event: Optional[QEvent])");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_ungrabMouseEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_ungrabMouseEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::ungrabMouseEvent(a0) : sipCpp->ungrabMouseEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_ungrabMouseEvent, doc_QGraphicsProxyWidget_ungrabMouseEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_mouseMoveEvent, "mouseMoveEvent(self, event: Optional[QGraphicsSceneMouseEvent])");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_mouseMoveEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_mouseMoveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsSceneMouseEvent* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QGraphicsSceneMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::mouseMoveEvent(a0) : sipCpp->mouseMoveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_mouseMoveEvent, doc_QGraphicsProxyWidget_mouseMoveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_mousePressEvent, "mousePressEvent(self, event: Optional[QGraphicsSceneMouseEvent])");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_mousePressEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_mousePressEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsSceneMouseEvent* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QGraphicsSceneMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::mousePressEvent(a0) : sipCpp->mousePressEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_mousePressEvent, doc_QGraphicsProxyWidget_mousePressEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_mouseReleaseEvent, "mouseReleaseEvent(self, event: Optional[QGraphicsSceneMouseEvent])");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_mouseReleaseEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_mouseReleaseEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsSceneMouseEvent* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QGraphicsSceneMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::mouseReleaseEvent(a0) : sipCpp->mouseReleaseEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_mouseReleaseEvent, doc_QGraphicsProxyWidget_mouseReleaseEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_mouseDoubleClickEvent, "mouseDoubleClickEvent(self, event: Optional[QGraphicsSceneMouseEvent])");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_mouseDoubleClickEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_mouseDoubleClickEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsSceneMouseEvent* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QGraphicsSceneMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::mouseDoubleClickEvent(a0) : sipCpp->mouseDoubleClickEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_mouseDoubleClickEvent, doc_QGraphicsProxyWidget_mouseDoubleClickEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_wheelEvent, "wheelEvent(self, event: Optional[QGraphicsSceneWheelEvent])");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_wheelEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_wheelEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsSceneWheelEvent* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QGraphicsSceneWheelEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::wheelEvent(a0) : sipCpp->wheelEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_wheelEvent, doc_QGraphicsProxyWidget_wheelEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_keyPressEvent, "keyPressEvent(self, event: Optional[QKeyEvent])");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_keyPressEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_keyPressEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QKeyEvent* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QKeyEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::keyPressEvent(a0) : sipCpp->keyPressEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_keyPressEvent, doc_QGraphicsProxyWidget_keyPressEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_keyReleaseEvent, "keyReleaseEvent(self, event: Optional[QKeyEvent])");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_keyReleaseEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_keyReleaseEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QKeyEvent* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QKeyEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::keyReleaseEvent(a0) : sipCpp->keyReleaseEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_keyReleaseEvent, doc_QGraphicsProxyWidget_keyReleaseEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_focusInEvent, "focusInEvent(self, event: Optional[QFocusEvent])");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_focusInEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_focusInEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QFocusEvent* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QFocusEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::focusInEvent(a0) : sipCpp->focusInEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_focusInEvent, doc_QGraphicsProxyWidget_focusInEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_focusOutEvent, "focusOutEvent(self, event: Optional[QFocusEvent])");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_focusOutEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_focusOutEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QFocusEvent* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QFocusEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::focusOutEvent(a0) : sipCpp->focusOutEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_focusOutEvent, doc_QGraphicsProxyWidget_focusOutEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_focusNextPrevChild, "focusNextPrevChild(self, next: bool) -> bool");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_focusNextPrevChild(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_focusNextPrevChild(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        bool a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pb", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::focusNextPrevChild(a0) : sipCpp->focusNextPrevChild(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_focusNextPrevChild, doc_QGraphicsProxyWidget_focusNextPrevChild);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_sizeHint, "sizeHint(self, which: Qt.SizeHint, constraint: QSizeF = QSizeF()) -> QSizeF");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_sizeHint(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_sizeHint(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::Qt::SizeHint a0;
        const ::QSizeF& a1def = QSizeF();
        const ::QSizeF* a1 = &a1def;
        const ::QGraphicsProxyWidget *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_constraint,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "pE|J9", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_Qt_SizeHint, &a0, sipType_QSizeF, &a1))
        {
            ::QSizeF*sipRes;

            sipRes = new ::QSizeF((sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::sizeHint(a0, *a1) : sipCpp->sizeHint(a0, *a1)));

            return sipConvertFromNewType(sipRes, sipType_QSizeF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_sizeHint, doc_QGraphicsProxyWidget_sizeHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_resizeEvent, "resizeEvent(self, event: Optional[QGraphicsSceneResizeEvent])");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_resizeEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_resizeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsSceneResizeEvent* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QGraphicsSceneResizeEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::resizeEvent(a0) : sipCpp->resizeEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_resizeEvent, doc_QGraphicsProxyWidget_resizeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_dragEnterEvent, "dragEnterEvent(self, event: Optional[QGraphicsSceneDragDropEvent])");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_dragEnterEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_dragEnterEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsSceneDragDropEvent* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QGraphicsSceneDragDropEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::dragEnterEvent(a0) : sipCpp->dragEnterEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_dragEnterEvent, doc_QGraphicsProxyWidget_dragEnterEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_dragLeaveEvent, "dragLeaveEvent(self, event: Optional[QGraphicsSceneDragDropEvent])");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_dragLeaveEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_dragLeaveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsSceneDragDropEvent* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QGraphicsSceneDragDropEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::dragLeaveEvent(a0) : sipCpp->dragLeaveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_dragLeaveEvent, doc_QGraphicsProxyWidget_dragLeaveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_dragMoveEvent, "dragMoveEvent(self, event: Optional[QGraphicsSceneDragDropEvent])");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_dragMoveEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_dragMoveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsSceneDragDropEvent* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QGraphicsSceneDragDropEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::dragMoveEvent(a0) : sipCpp->dragMoveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_dragMoveEvent, doc_QGraphicsProxyWidget_dragMoveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_dropEvent, "dropEvent(self, event: Optional[QGraphicsSceneDragDropEvent])");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_dropEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_dropEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsSceneDragDropEvent* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QGraphicsSceneDragDropEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::dropEvent(a0) : sipCpp->dropEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_dropEvent, doc_QGraphicsProxyWidget_dropEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_newProxyWidget, "newProxyWidget(self, a0: Optional[QWidget]) -> Optional[QGraphicsProxyWidget]");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_newProxyWidget(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_newProxyWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWidget* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QWidget, &a0))
        {
            ::QGraphicsProxyWidget*sipRes;

            sipRes = sipCpp->newProxyWidget(a0);

            return sipConvertFromNewType(sipRes, sipType_QGraphicsProxyWidget, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_newProxyWidget, doc_QGraphicsProxyWidget_newProxyWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_inputMethodQuery, "inputMethodQuery(self, query: Qt.InputMethodQuery) -> Any");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_inputMethodQuery(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_inputMethodQuery(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::Qt::InputMethodQuery a0;
        const ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pE", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_Qt_InputMethodQuery, &a0))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant((sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::inputMethodQuery(a0) : sipCpp->inputMethodQuery(a0)));

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_inputMethodQuery, doc_QGraphicsProxyWidget_inputMethodQuery);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsProxyWidget_inputMethodEvent, "inputMethodEvent(self, event: Optional[QInputMethodEvent])");

extern "C" {static PyObject *meth_QGraphicsProxyWidget_inputMethodEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsProxyWidget_inputMethodEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QInputMethodEvent* a0;
        ::QGraphicsProxyWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsProxyWidget, &sipCpp, sipType_QInputMethodEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsProxyWidget::inputMethodEvent(a0) : sipCpp->inputMethodEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsProxyWidget, sipName_inputMethodEvent, doc_QGraphicsProxyWidget_inputMethodEvent);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QGraphicsProxyWidget(void *, const sipTypeDef *);}
static void *cast_QGraphicsProxyWidget(void *sipCppV, const sipTypeDef *targetType)
{
    ::QGraphicsProxyWidget *sipCpp = reinterpret_cast< ::QGraphicsProxyWidget *>(sipCppV);

    if (targetType == sipType_QGraphicsProxyWidget)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QGraphicsWidget)->ctd_cast(static_cast< ::QGraphicsWidget *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QGraphicsProxyWidget(void *, int);}
static void release_QGraphicsProxyWidget(void *sipCppV, int)
{
    ::QGraphicsProxyWidget *sipCpp = reinterpret_cast< ::QGraphicsProxyWidget *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QGraphicsProxyWidget(Py_ssize_t);}
static void *array_QGraphicsProxyWidget(Py_ssize_t sipNrElem)
{
    return new ::QGraphicsProxyWidget[sipNrElem];
}


extern "C" {static void array_delete_QGraphicsProxyWidget(void *);}
static void array_delete_QGraphicsProxyWidget(void *sipCpp)
{
    delete[] reinterpret_cast< ::QGraphicsProxyWidget *>(sipCpp);
}


extern "C" {static void dealloc_QGraphicsProxyWidget(sipSimpleWrapper *);}
static void dealloc_QGraphicsProxyWidget(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQGraphicsProxyWidget *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGraphicsProxyWidget(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QGraphicsProxyWidget(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGraphicsProxyWidget(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQGraphicsProxyWidget *sipCpp = SIP_NULLPTR;

    {
        ::QGraphicsItem* a0 = 0;
        ::Qt::WindowFlags a1def = Qt::WindowFlags();
        ::Qt::WindowFlags* a1 = &a1def;
        int a1State = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
            sipName_flags,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JHJ1", sipType_QGraphicsItem, &a0, sipOwner, sipType_Qt_WindowFlags, &a1, &a1State))
        {
            sipCpp = new sipQGraphicsProxyWidget(a0, *a1);
            sipReleaseType(a1, sipType_Qt_WindowFlags, a1State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QGraphicsProxyWidget[] = {{172, 255, 1}};


static PyMethodDef methods_QGraphicsProxyWidget[] = {
    {sipName_contextMenuEvent, meth_QGraphicsProxyWidget_contextMenuEvent, METH_VARARGS, doc_QGraphicsProxyWidget_contextMenuEvent},
    {sipName_createProxyForChildWidget, meth_QGraphicsProxyWidget_createProxyForChildWidget, METH_VARARGS, doc_QGraphicsProxyWidget_createProxyForChildWidget},
    {sipName_dragEnterEvent, meth_QGraphicsProxyWidget_dragEnterEvent, METH_VARARGS, doc_QGraphicsProxyWidget_dragEnterEvent},
    {sipName_dragLeaveEvent, meth_QGraphicsProxyWidget_dragLeaveEvent, METH_VARARGS, doc_QGraphicsProxyWidget_dragLeaveEvent},
    {sipName_dragMoveEvent, meth_QGraphicsProxyWidget_dragMoveEvent, METH_VARARGS, doc_QGraphicsProxyWidget_dragMoveEvent},
    {sipName_dropEvent, meth_QGraphicsProxyWidget_dropEvent, METH_VARARGS, doc_QGraphicsProxyWidget_dropEvent},
    {sipName_event, meth_QGraphicsProxyWidget_event, METH_VARARGS, doc_QGraphicsProxyWidget_event},
    {sipName_eventFilter, meth_QGraphicsProxyWidget_eventFilter, METH_VARARGS, doc_QGraphicsProxyWidget_eventFilter},
    {sipName_focusInEvent, meth_QGraphicsProxyWidget_focusInEvent, METH_VARARGS, doc_QGraphicsProxyWidget_focusInEvent},
    {sipName_focusNextPrevChild, meth_QGraphicsProxyWidget_focusNextPrevChild, METH_VARARGS, doc_QGraphicsProxyWidget_focusNextPrevChild},
    {sipName_focusOutEvent, meth_QGraphicsProxyWidget_focusOutEvent, METH_VARARGS, doc_QGraphicsProxyWidget_focusOutEvent},
    {sipName_grabMouseEvent, meth_QGraphicsProxyWidget_grabMouseEvent, METH_VARARGS, doc_QGraphicsProxyWidget_grabMouseEvent},
    {sipName_hideEvent, meth_QGraphicsProxyWidget_hideEvent, METH_VARARGS, doc_QGraphicsProxyWidget_hideEvent},
    {sipName_hoverEnterEvent, meth_QGraphicsProxyWidget_hoverEnterEvent, METH_VARARGS, doc_QGraphicsProxyWidget_hoverEnterEvent},
    {sipName_hoverLeaveEvent, meth_QGraphicsProxyWidget_hoverLeaveEvent, METH_VARARGS, doc_QGraphicsProxyWidget_hoverLeaveEvent},
    {sipName_hoverMoveEvent, meth_QGraphicsProxyWidget_hoverMoveEvent, METH_VARARGS, doc_QGraphicsProxyWidget_hoverMoveEvent},
    {sipName_inputMethodEvent, meth_QGraphicsProxyWidget_inputMethodEvent, METH_VARARGS, doc_QGraphicsProxyWidget_inputMethodEvent},
    {sipName_inputMethodQuery, meth_QGraphicsProxyWidget_inputMethodQuery, METH_VARARGS, doc_QGraphicsProxyWidget_inputMethodQuery},
    {sipName_itemChange, meth_QGraphicsProxyWidget_itemChange, METH_VARARGS, doc_QGraphicsProxyWidget_itemChange},
    {sipName_keyPressEvent, meth_QGraphicsProxyWidget_keyPressEvent, METH_VARARGS, doc_QGraphicsProxyWidget_keyPressEvent},
    {sipName_keyReleaseEvent, meth_QGraphicsProxyWidget_keyReleaseEvent, METH_VARARGS, doc_QGraphicsProxyWidget_keyReleaseEvent},
    {sipName_mouseDoubleClickEvent, meth_QGraphicsProxyWidget_mouseDoubleClickEvent, METH_VARARGS, doc_QGraphicsProxyWidget_mouseDoubleClickEvent},
    {sipName_mouseMoveEvent, meth_QGraphicsProxyWidget_mouseMoveEvent, METH_VARARGS, doc_QGraphicsProxyWidget_mouseMoveEvent},
    {sipName_mousePressEvent, meth_QGraphicsProxyWidget_mousePressEvent, METH_VARARGS, doc_QGraphicsProxyWidget_mousePressEvent},
    {sipName_mouseReleaseEvent, meth_QGraphicsProxyWidget_mouseReleaseEvent, METH_VARARGS, doc_QGraphicsProxyWidget_mouseReleaseEvent},
    {sipName_newProxyWidget, meth_QGraphicsProxyWidget_newProxyWidget, METH_VARARGS, doc_QGraphicsProxyWidget_newProxyWidget},
    {sipName_paint, meth_QGraphicsProxyWidget_paint, METH_VARARGS, doc_QGraphicsProxyWidget_paint},
    {sipName_resizeEvent, meth_QGraphicsProxyWidget_resizeEvent, METH_VARARGS, doc_QGraphicsProxyWidget_resizeEvent},
    {sipName_setGeometry, meth_QGraphicsProxyWidget_setGeometry, METH_VARARGS, doc_QGraphicsProxyWidget_setGeometry},
    {sipName_setWidget, meth_QGraphicsProxyWidget_setWidget, METH_VARARGS, doc_QGraphicsProxyWidget_setWidget},
    {sipName_showEvent, meth_QGraphicsProxyWidget_showEvent, METH_VARARGS, doc_QGraphicsProxyWidget_showEvent},
    {sipName_sizeHint, SIP_MLMETH_CAST(meth_QGraphicsProxyWidget_sizeHint), METH_VARARGS|METH_KEYWORDS, doc_QGraphicsProxyWidget_sizeHint},
    {sipName_subWidgetRect, meth_QGraphicsProxyWidget_subWidgetRect, METH_VARARGS, doc_QGraphicsProxyWidget_subWidgetRect},
    {sipName_type, meth_QGraphicsProxyWidget_type, METH_VARARGS, doc_QGraphicsProxyWidget_type},
    {sipName_ungrabMouseEvent, meth_QGraphicsProxyWidget_ungrabMouseEvent, METH_VARARGS, doc_QGraphicsProxyWidget_ungrabMouseEvent},
    {sipName_wheelEvent, meth_QGraphicsProxyWidget_wheelEvent, METH_VARARGS, doc_QGraphicsProxyWidget_wheelEvent},
    {sipName_widget, meth_QGraphicsProxyWidget_widget, METH_VARARGS, doc_QGraphicsProxyWidget_widget}
};

PyDoc_STRVAR(doc_QGraphicsProxyWidget, "\1QGraphicsProxyWidget(parent: Optional[QGraphicsItem] = None, flags: Union[Qt.WindowFlags, Qt.WindowType] = Qt.WindowFlags())");


static pyqt5ClassPluginDef plugin_QGraphicsProxyWidget = {
    &::QGraphicsProxyWidget::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsProxyWidget = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGraphicsProxyWidget,
        SIP_NULLPTR,
        &plugin_QGraphicsProxyWidget,
    },
    {
        sipNameNr_QGraphicsProxyWidget,
        {0, 0, 1},
        37, methods_QGraphicsProxyWidget,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGraphicsProxyWidget,
    -1,
    -1,
    supers_QGraphicsProxyWidget,
    SIP_NULLPTR,
    init_type_QGraphicsProxyWidget,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGraphicsProxyWidget,
    SIP_NULLPTR,
    array_QGraphicsProxyWidget,
    SIP_NULLPTR,
    release_QGraphicsProxyWidget,
    cast_QGraphicsProxyWidget,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QGraphicsProxyWidget,
    sizeof (::QGraphicsProxyWidget),
};
